@@ -1,4 +1,4 @@
-from .logging import configureLogging
+from .logger import configureLogging
 from .version import getVersionFromSetup
 
 __all__ = ['configureLogging', 'getVersionFromSetup']
